/*
 * Copyright 2020 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "fBody.h"
#include "wTag.h"
#include <iomanip>
#include <fstream>
using namespace tbox;
using namespace fpm;

Body::Body(std::shared_ptr<MshData> _msh, std::string const &name) : Group(_msh, name), Cl(0), Cd(0), Cs(0), Cm(0)
{
    cLoadX.resize(tag->elems.size());
    cLoadY.resize(tag->elems.size());
    cLoadZ.resize(tag->elems.size());
}

/**
 * @brief Save global quantities to file
 */
void Body::save(std::string const &name)
{
    // Write to file
    std::cout << "writing file: " << name + ".dat"
              << "... " << std::flush;
    std::ofstream outfile;
    outfile.open(name + ".dat");
    // Header
    outfile << "$Body - " << tag->name << std::endl;
    // Element count
    outfile << "$Elements" << std::endl;
    outfile << tag->elems.size();
    // Aerodynamic coefficients
    outfile << "$Aerodynamic coefficients" << std::endl;
    outfile << "#" << std::fixed
            << std::setw(14) << "Cl"
            << std::setw(15) << "Cd"
            << std::setw(15) << "Cs"
            << std::setw(15) << "Cm"
            << std::endl;
    outfile << std::fixed
            << std::setw(15) << Cl
            << std::setw(15) << Cd
            << std::setw(15) << Cs
            << std::setw(15) << Cm
            << std::endl;
    // Footer
    outfile << std::endl;
    // Close file
    outfile.close();
    std::cout << "done!" << std::endl;
}

void Body::write(std::ostream &out) const
{
    out << "fpm::Body " << *tag << std::endl;
}
