/*
 * Copyright 2020 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef FLIFTING_H
#define FLIFTING_H

#include "fpm.h"
#include "fBody.h"
#include "fWake.h"

namespace fpm
{

/**
 * @brief Manage a lifting body immersed in the fluid
 * @authors Adrien Crovato
 */
class FPM_API Lifting : public Body
{
public:
    Wake *wake; ///< wake attached to the lifting surface

    Lifting(std::shared_ptr<tbox::MshData> _msh, std::vector<std::string> const &names, double xF);
    ~Lifting();

#ifndef SWIG
    virtual void write(std::ostream &out) const override;
#endif
};

} // namespace fpm

#endif //FLIFTING_H
